# Filename:     tb_hall_sensor_sim.do
# Filetype:     Modelsim Script File
# Date:         23 sep 2012
# Update:       -
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Demo
# Error:        -
# Version:      1.1
# Copyright:    (c)2012, De Haagse Hogeschool

# Set transcript on
transcript on

# Recreate the work directory and map to work
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
# (or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile the Hall Sensor VHDL description and testbench,
# please note that the design and its testbench is located
# in the project root, but the simulator start in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -2008 -work work ${prefix}hall_sensor_sim.vhd
vcom -2008 -work work ${prefix}tb_hall_sensor_sim.vhd

# Start the simulator with 1 ns time resolution
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" tb_hall_sensor_sim

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
#add list *
#add list dut/counter
#add list -radix hex bcd

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "SYSTEM"
add wave CLOCK_50
add wave -divider "Inputs"
add wave SW
add wave BUTTON
add wave -divider "Internals"
add wave dut/clk
add wave dut/areset
add wave dut/speed
add wave dut/pulse_counter
add wave dut/rep_counter
add wave dut/hall_sensor
add wave dut/state
add wave dut/sync_output
add wave -divider "Outputs"
add wave LEDG
add wave HALL_SEN
add wave SYNC_OUT

# Open Structure, Signals (waveform) and List window
view structure
view list
view signals
view wave

# Run simulation for ...
run 720000 us

# Fill up the waveform in the window
wave zoom full
