library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity tb_hall_sensor_sim is
end entity;

architecture sim of tb_hall_sensor_sim is
constant small_delay : time := 1 ns;
-- The module
component hall_sensor_sim is
	port (CLOCK_50 : in std_logic;
			BUTTON   : in std_logic_vector(2 downto 0);
			SW       : in std_logic_vector(9 downto 0);
			LEDG     : out std_logic_vector(9 downto 0);
			HEX3_D   : out std_logic_vector(6 downto 0);
			HEX2_D   : out std_logic_vector(6 downto 0);
			HEX1_D   : out std_logic_vector(6 downto 0);
			HEX0_D   : out std_logic_vector(6 downto 0);
			HEX0_DP  : out std_logic;
			HEX1_DP  : out std_logic;
			HEX2_DP  : out std_logic;
			HEX3_DP  : out std_logic;
			-- Hall Sensor Output, mapped to extension header
			HALL_SEN : out std_logic;
			SYNC_OUT : out std_logic
		);
end component hall_sensor_sim;

-- Signals to be traced, from the module
signal CLOCK_50 : std_logic;
signal BUTTON   : std_logic_vector(2 downto 0);
signal SW       : std_logic_vector(9 downto 0);
signal LEDG     : std_logic_vector(9 downto 0);
signal HEX3_D   : std_logic_vector(6 downto 0);
signal HEX2_D   : std_logic_vector(6 downto 0);
signal HEX1_D   : std_logic_vector(6 downto 0);
signal HEX0_D   : std_logic_vector(6 downto 0);
signal HEX0_DP  : std_logic;
signal HEX1_DP  : std_logic;
signal HEX2_DP  : std_logic;
signal HEX3_DP  : std_logic;
signal HALL_SEN : std_logic;
signal SYNC_OUT : std_logic;

begin

	dut: hall_sensor_sim
	port map (CLOCK_50 => CLOCK_50, BUTTON => BUTTON, SW => SW, LEDG => LEDG,
				 HEX3_D => HEX3_D, HEX2_D => HEX2_D, HEX1_D => HEX1_D, HEX0_D => HEX0_D,
				 HEX0_DP => HEX0_DP, HEX1_DP => HEX1_DP, HEX2_DP => HEX2_DP, HEX3_DP => HEX3_DP,
				 HALL_SEN => HALL_SEN, SYNC_OUT => SYNC_OUT);

	clockgen: process is
	begin
		-- give time for reset
		CLOCK_50 <= '0';
		BUTTON(0) <= '0';
		wait for 15 ns;
		BUTTON(0) <= '1';
		wait for 5 ns;
		-- forever: generate clock cycle for 20 ns and 50% d.c.
		loop
			CLOCK_50 <= '1';
			wait for 10 ns;
			CLOCK_50 <= '0';
			wait for 10 ns;
		end loop;

	end process;
	
	datagen: process is
	begin
		BUTTON(2 downto 1) <= (others => '0');
		SW(0 downto 0) <= (others => '0');
		SW(1 downto 0) <= "10";
		wait;
	end process;
	
end architecture;